@@ -43,6 +43,7 @@
 
 #ifdef GLOM_ENABLE_MAEMO
 #include <hildon/hildon-window.h>
+#include <hildon-fmmm.h>
 #endif // GLOM_ENABLE_MAEMO
 
 #ifndef G_OS_WIN32
@@ -102,35 +103,13 @@ App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& bu
   m_menu_print_layouts_ui_merge_id(0),
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   m_ui_save_extra_showextras(false),
-  m_ui_save_extra_newdb_hosting_mode(Document::DEFAULT_HOSTED),
-
-#endif // !GLOM_ENABLE_CLIENT_ONLY
+  m_ui_save_extra_newdb_hosting_mode(Document::HOSTING_MODE_DEFAULT),
   m_avahi_progress_dialog(0),
+#endif // !GLOM_ENABLE_CLIENT_ONLY
   m_show_sql_debug(false)
 {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  try
-#else
-  std::auto_ptr<Glib::Error> error;
-#endif
-  {
-    //Show the icon in the window manager's window title bar and in the list of running applications:
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-    set_icon_from_file(GLOM_ICON_DIR "/glom.png");
-#else
-    set_icon_from_file(GLOM_ICON_DIR "/glom.png", error);
-#endif
-  }
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-  catch(const Glib::Error& ex)
-  {
-#else
-  if(error.get() != NULL)
-  {
-    const Glib::Error& ex = *error.get();
-#endif
-    std::cerr << "App_Glom::App_Glom(): Could not set icon: " << ex.what() << std::endl;
-  } 
+  // TODO: Wrap missing method in gtkmm
+  gtk_window_set_icon_name(GTK_WINDOW(gobj()), "glom");
 
   //Load widgets from glade file:
   builder->get_widget("bakery_vbox", m_pBoxTop);
@@ -138,10 +117,8 @@ App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& bu
   builder->get_widget_derived("vbox_frame", m_pFrame); //This one is derived. There's a lot happening here.
 
   add_mime_type("application/x-glom"); //TODO: make this actually work - we need to register it properly.
-
-  //Hide the toolbar because it doesn't contain anything useful for this app.
-  m_HandleBox_Toolbar.hide();
   
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   //Install UI hooks for this:
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
   if(!connection_pool)
@@ -149,7 +126,8 @@ App_Glom::App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& bu
       sigc::mem_fun(*this, &App_Glom::on_connection_avahi_begin),
       sigc::mem_fun(*this, &App_Glom::on_connection_avahi_progress),
       sigc::mem_fun(*this, &App_Glom::on_connection_avahi_done) );     
-  
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
   global_application = this;
 }
 
@@ -161,15 +139,16 @@ App_Glom::~App_Glom()
     m_pFrame->remove_view(m_window_translations);
     delete m_window_translations;
   }
-#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   if(m_avahi_progress_dialog)
   {
     delete m_avahi_progress_dialog;
     m_avahi_progress_dialog = 0;
   }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void App_Glom::on_connection_avahi_begin()
 {
   //Create the dialog:
@@ -201,20 +180,18 @@ void App_Glom::on_connection_avahi_done()
     m_avahi_progress_dialog = 0;
   }
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 bool App_Glom::init(const Glib::ustring& document_uri)
 {
   type_vec_strings vecAuthors;
   vecAuthors.push_back("Murray Cumming <murrayc@murrayc.com>");
-  set_about_information(VERSION, vecAuthors, _("(C) 2000-2005 Murray Cumming"), _("A Database GUI"));
+  set_about_information(PACKAGE_VERSION, vecAuthors, _("(C) 2000-2005 Murray Cumming"), _("A Database GUI"));
 
   type_base::init(); //calls init_menus() and init_toolbars()
 
   //m_pFrame->set_shadow_type(Gtk::SHADOW_IN);
 
-  //Hide the toolbar because it doesn't contain anything useful for this app.
-  //m_HandleBox_Toolbar.hide();
-
   if(document_uri.empty())
   {
     Document* pDocument = static_cast<Document*>(get_document());
@@ -250,6 +227,7 @@ void App_Glom::init_layout()
 
   //Add menu bar at the top:
   //These were defined in init_uimanager().
+#undef GLOM_ENABLE_MAEMO // TODO: Fix menu!
 #ifdef GLOM_ENABLE_MAEMO
   Gtk::Menu* pMenu = static_cast<Gtk::Menu*>(m_refUIManager->get_widget("/Bakery_MainMenu"));
   set_menu(*pMenu);
@@ -258,15 +236,8 @@ void App_Glom::init_layout()
   m_pBoxTop->pack_start(*pMenuBar, Gtk::PACK_SHRINK);
 #endif
 
-  //Do not create the toolbar because it doesn't contain anything useful for this app.
-  //Gtk::Toolbar* pToolBar = static_cast<Gtk::Toolbar*>(m_refUIManager->get_widget("/Bakery_ToolBar"));
-  //m_HandleBox_Toolbar.add(*pToolBar);
-  //m_HandleBox_Toolbar.show();
-
   add_accel_group(m_refUIManager->get_accel_group());
 
-  //m_pBoxTop->pack_start(m_HandleBox_Toolbar, Gtk::PACK_SHRINK);
-
   //Add placeholder, to be used by add():
   //m_pBoxTop->pack_start(m_VBox_PlaceHolder);
   //m_VBox_PlaceHolder.show();
@@ -330,10 +301,13 @@ void App_Glom::init_menus_file()
 
   m_toggleaction_network_shared = Gtk::ToggleAction::create("BakeryAction_Menu_File_Share", _("Shared On Network"));
   m_refFileActionGroup->add(m_toggleaction_network_shared);
+
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   m_connection_toggleaction_network_shared = 
     m_toggleaction_network_shared->signal_toggled().connect(
       sigc::mem_fun(*this, &App_Glom::on_menu_file_toggle_share) );
   m_listDeveloperActions.push_back(m_toggleaction_network_shared);
+#endif //!GLOM_ENABLE_CLIENT_ONLY
 
   m_refFileActionGroup->add(Gtk::Action::create("GlomAction_Menu_File_Print", Gtk::Stock::PRINT));
   m_refFileActionGroup->add(Gtk::Action::create("GlomAction_File_Print", _("_Standard")),
@@ -614,6 +588,7 @@ void App_Glom::init_menus()
   fill_menu_tables();
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void App_Glom::on_menu_file_toggle_share()
 {
   if(!m_pFrame)
@@ -622,7 +597,6 @@ void App_Glom::on_menu_file_toggle_share()
   m_pFrame->on_menu_file_toggle_share(m_toggleaction_network_shared);
 }
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
 void App_Glom::on_menu_userlevel_developer()
 {
   if(!m_pFrame)
@@ -670,6 +644,18 @@ static bool hostname_is_localhost(const Glib::ustring& hostname)
   return true;
 }
 
+void App_Glom::ui_warning_load_failed(int failure_code)
+{
+  if(failure_code == Document::LOAD_FAILURE_CODE_FILE_VERSION_TOO_NEW)
+  {
+    ui_warning(_("Open Failed."), 
+      _("The document could not be opened because it was created or modified by a newer version of Glom."));
+  }
+  else
+    GlomBakery::App_WithDoc_Gtk::ui_warning_load_failed();
+}
+
+
 #ifndef G_OS_WIN32
 void App_Glom::open_browsed_document(const EpcServiceInfo* server, const Glib::ustring& service_name)
 {
@@ -738,7 +724,8 @@ void App_Glom::open_browsed_document(const EpcServiceInfo* server, const Glib::u
   {
     //Create a temporary Document instance, so we can manipulate the data:
     Document document_temp;
-    const bool loaded = document_temp.load_from_data((const guchar*)document_contents, length);
+    int failure_code = 0;
+    const bool loaded = document_temp.load_from_data((const guchar*)document_contents, length, failure_code);
     if(loaded)
     {
       // Connection is always remote-hosted in client only mode:
@@ -758,13 +745,13 @@ void App_Glom::open_browsed_document(const EpcServiceInfo* server, const Glib::u
       if(hostname_is_localhost(host))
         document_temp.set_connection_server( epc_service_info_get_host(server) );
 
-      //Make sure that we only use the specified port instead of connectin to some other postgres instance 
+      //Make sure that we only use the specified port instead of connecting to some other postgres instance 
       //on the same server:
       document_temp.set_connection_try_other_ports(false);
     }
     else
     {
-      std::cerr << "Could not parse the document that was retrieved over the network." << std::endl;
+      std::cerr << "Could not parse the document that was retrieved over the network: failure_code=" << failure_code << std::endl;
     }
 
     g_free(document_contents);
@@ -784,12 +771,13 @@ void App_Glom::open_browsed_document(const EpcServiceInfo* server, const Glib::u
     if(document)
     {
       document->set_opened_from_browse();
+      document->set_userlevel(AppState::USERLEVEL_OPERATOR); //TODO: This should happen automatically.
 
       document->set_network_shared(true); //It is shared by the computer that we opened this from.
       update_network_shared_ui();
 
-      document->set_userlevel(AppState::USERLEVEL_OPERATOR); //TODO: This should happen automatically.
 #ifndef GLOM_ENABLE_CLIENT_ONLY
+
       update_userlevel_ui();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
     }
@@ -976,7 +964,7 @@ bool App_Glom::on_document_load()
         m_ui_save_extra_title = _("Creating From Example File");
         m_ui_save_extra_message = _("To use this example file you must save an editable copy of the file. A new database will also be created on the server.");
         m_ui_save_extra_newdb_title = "TODO";
-        m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED;
+        m_ui_save_extra_newdb_hosting_mode = Document::HOSTING_MODE_DEFAULT;
 
         
         // Reinit cancelled state
@@ -993,8 +981,15 @@ bool App_Glom::on_document_load()
           //Get the results from the extended save dialog:
           pDocument->set_database_title(m_ui_save_extra_newdb_title);
           pDocument->set_hosting_mode(m_ui_save_extra_newdb_hosting_mode);
-          m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED;
+          m_ui_save_extra_newdb_hosting_mode = Document::HOSTING_MODE_DEFAULT;
           pDocument->set_is_example_file(false);
+
+          // For self-hosting, we will choose a port later. For central
+          // hosting, try several default ports. Don't use the values that
+          // are set in the example file.
+          pDocument->set_connection_port(0);
+          pDocument->set_connection_try_other_ports(true);
+
           // We have a valid uri, so we can set it to !new and modified here
         }        
         
@@ -1046,7 +1041,7 @@ bool App_Glom::on_document_load()
         connection_pool->set_get_document_func( sigc::mem_fun(*this, &App_Glom::on_connection_pool_get_document) );
 #endif
 
-        connection_pool->set_ready_to_connect(true); //Box_WithButtons::connect_to_server() will now attempt the connection-> Shared instances of m_Connection will also be usable.
+        connection_pool->set_ready_to_connect(true); //connect_to_server() will now attempt the connection-> Shared instances of m_Connection will also be usable.
 
         //Attempt to connect to the specified database:
         bool test = false;
@@ -1067,7 +1062,11 @@ bool App_Glom::on_document_load()
           //Use the default username/password if opening as non network-shared:
           if(!(pDocument->get_network_shared()))
           {
-            m_temp_username = Privs::get_default_developer_user_name(m_temp_password);
+            // If the document is centrally hosted, don't pretend to know the
+            // username or password, because we don't. The user will enter
+            // the login credentials in a dialog.
+            if(pDocument->get_hosting_mode() != Document::HOSTING_MODE_POSTGRES_CENTRAL)
+              m_temp_username = Privs::get_default_developer_user_name(m_temp_password);
           }
 
           bool database_not_found = false;
@@ -1147,6 +1146,7 @@ bool App_Glom::on_document_load()
     update_network_shared_ui();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
+
     pDocument->set_allow_autosave(true);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -1185,12 +1185,6 @@ void App_Glom::statusbar_clear()
 */
 
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-void App_Glom::on_userlevel_changed(AppState::userlevels /* userlevel */)
-{
-  update_userlevel_ui();
-}
-
 void App_Glom::update_network_shared_ui()
 {
   Document* document = dynamic_cast<Document*>(get_document());
@@ -1215,6 +1209,12 @@ void App_Glom::update_network_shared_ui()
   m_connection_toggleaction_network_shared.unblock();
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+void App_Glom::on_userlevel_changed(AppState::userlevels /* userlevel */)
+{
+  update_userlevel_ui();
+}
+
 void App_Glom::update_userlevel_ui()
 {
   AppState::userlevels userlevel = get_userlevel();
@@ -1258,15 +1258,13 @@ Glib::RefPtr<Gtk::UIManager> App_Glom::get_ui_manager()
 
 bool App_Glom::offer_new_or_existing()
 {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
   //Offer to load an existing document, or start a new one.
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_existing_or_new");
 #else
   std::auto_ptr<Glib::Error> error;
-  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_existing_or_new", "", error);
-  if(error.get())
-    return false;
-#endif
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_existing_or_new", error);
+#endif      
 
   Dialog_ExistingOrNew* dialog_raw = 0;
   refXml->get_widget_derived("dialog_existing_or_new", dialog_raw);
@@ -1336,7 +1334,7 @@ void App_Glom::existing_or_new_new()
   Glib::ustring db_title;
 
   m_ui_save_extra_showextras = true; //Offer self-hosting or central hosting, and offer the database title.
-  m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED; /* Default to self-hosting */
+  m_ui_save_extra_newdb_hosting_mode = Document::HOSTING_MODE_DEFAULT; /* Default to self-hosting */
   m_ui_save_extra_newdb_title.clear();
   offer_saveas();
 
@@ -1348,13 +1346,13 @@ void App_Glom::existing_or_new_new()
     const Glib::ustring db_title = m_ui_save_extra_newdb_title;
     Document::HostingMode hosting_mode = m_ui_save_extra_newdb_hosting_mode;
     m_ui_save_extra_newdb_title.clear();
-    m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED;
+    m_ui_save_extra_newdb_hosting_mode = Document::HOSTING_MODE_DEFAULT;
 
     //Make sure that the user can do something with his new document:
     document->set_userlevel(AppState::USERLEVEL_DEVELOPER);
     // Try various ports if connecting to an existing database server instead
     // of self-hosting one:
-    document->set_connection_try_other_ports(m_ui_save_extra_newdb_hosting_mode == Document::DEFAULT_HOSTED);
+    document->set_connection_try_other_ports(m_ui_save_extra_newdb_hosting_mode == Document::HOSTING_MODE_DEFAULT);
 
     //Each new document must have an associated new database,
     //so choose a name
@@ -1394,6 +1392,9 @@ void App_Glom::existing_or_new_new()
         ConnectionPool::get_instance()->set_database(database_name_used);
         document->set_database_title(db_title);
         m_pFrame->set_databases_selected(database_name_used);
+
+        // Add the document to recent files
+	document_history_add(document->get_file_uri());
       }
       else
       {
@@ -1981,7 +1982,7 @@ void App_Glom::on_menu_file_save_as_example()
   m_ui_save_extra_title.clear();
   m_ui_save_extra_message.clear();
   m_ui_save_extra_newdb_title.clear();
-  m_ui_save_extra_newdb_hosting_mode = Document::DEFAULT_HOSTED;
+  m_ui_save_extra_newdb_hosting_mode = Document::HOSTING_MODE_DEFAULT;
 
   Glib::ustring file_uri = ui_file_select_save(file_uriOld); //Also asks for overwrite confirmation.
   if(!file_uri.empty())
@@ -2393,7 +2394,8 @@ void App_Glom::on_menu_developer_changelanguage()
 
        //Get the translations from the document (in Operator mode, we only load the necessary translations.)
        //This also updates the UI, so we show all the translated titles:
-       get_document()->load();
+       int failure_code = 0;
+       get_document()->load(failure_code);
 
        m_pFrame->show_table_refresh(); //load() doesn't seem to refresh the view.
       }
