@@ -21,10 +21,10 @@
 #ifndef HEADER_APP_GLOM
 #define HEADER_APP_GLOM
 
-#include "bakery/bakery.h"
-#include "frame_glom.h"
+#include <glom/bakery/app_withdoc_gtk.h>
+#include <glom/frame_glom.h>
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 
 //Avoid including the header here:
@@ -40,10 +40,10 @@ namespace Glom
 
 class Window_Translations;
 
-class App_Glom : public Bakery::App_WithDoc_Gtk
+class App_Glom : public GlomBakery::App_WithDoc_Gtk
 {
 public:
-  App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  App_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~App_Glom();
 
   virtual bool init(const Glib::ustring& document_uri = Glib::ustring()); //override
@@ -59,10 +59,16 @@ public:
   void set_mode_data();
   void set_mode_find();
 
+  /** Show in the UI whether the database is shared on the network.
+   */
+  void update_network_shared_ui();
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void add_developer_action(const Glib::RefPtr<Gtk::Action>& refAction);
   void remove_developer_action(const Glib::RefPtr<Gtk::Action>& refAction);
 
+  /** Show in the UI whether the document is in developer or operator mode.
+   */
   void update_userlevel_ui();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -83,6 +89,9 @@ public:
 
   static App_Glom* get_application();
 
+protected:
+  virtual void ui_warning_load_failed(int failure_code = 0); //Override.
+
 private:
   virtual void init_layout(); //override.
   virtual void init_menus_file(); //override.
@@ -91,15 +100,16 @@ private:
   virtual void init_toolbars(); //override
   virtual void init_create_document(); //override
   virtual bool on_document_load(); //override.
-  
-  virtual void add_ui_from_string(const Glib::ustring& ui_description);
+  virtual void on_document_close(); //override.
 
   bool offer_new_or_existing();
 
   void on_menu_help_contents();
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void existing_or_new_new();
 
+  void on_menu_file_toggle_share();
   void on_menu_userlevel_developer();
   void on_menu_userlevel_operator();
   void on_menu_file_save_as_example();
@@ -114,10 +124,14 @@ private:
   virtual Glib::ustring ui_file_select_save(const Glib::ustring& old_file_uri); //overridden.
   void on_userlevel_changed(AppState::userlevels userlevel);
 
-  Document_Glom* on_connection_pool_get_document();
+  Document* on_connection_pool_get_document();
 
   bool recreate_database(bool& user_cancelled); //return indicates success.
   void stop_self_hosting_of_document_database();
+  
+  void on_connection_avahi_begin();
+  void on_connection_avahi_progress();
+  void on_connection_avahi_done();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 #ifndef G_OS_WIN32
@@ -132,7 +146,9 @@ private:
   virtual void on_menu_file_close(); //override.
   virtual void document_history_add(const Glib::ustring& file_uri); //overridden.
 
-  virtual Bakery::App* new_instance(); //Override
+  virtual void new_instance(const Glib::ustring& uri = Glib::ustring()); //Override
+  
+  void on_connection_close_progress();
 
 #ifndef G_OS_WIN32
   void open_browsed_document(const EpcServiceInfo* server, const Glib::ustring& service_name);
@@ -140,7 +156,7 @@ private:
 
   static Glib::ustring get_file_uri_without_extension(const Glib::ustring& uri);
 
-  typedef Bakery::App_WithDoc_Gtk type_base;
+  typedef GlomBakery::App_WithDoc_Gtk type_base;
 
   //Widgets:
 
@@ -155,6 +171,9 @@ private:
   Glib::RefPtr<Gtk::ToggleAction> m_action_show_layout_toolbar;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+  Glib::RefPtr<Gtk::ToggleAction> m_toggleaction_network_shared;
+  sigc::connection m_connection_toggleaction_network_shared;
+
   Gtk::VBox* m_pBoxTop;
   Gtk::VBox* m_pBoxSidebar;
   Frame_Glom* m_pFrame;
@@ -176,7 +195,9 @@ private:
 
   Glib::ustring m_ui_save_extra_newdb_title;
 
-  Document_Glom::HostingMode m_ui_save_extra_newdb_hosting_mode;
+  Document::HostingMode m_ui_save_extra_newdb_hosting_mode;
+
+  Gtk::MessageDialog* m_avahi_progress_dialog;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   // This is set to the URI of an example file that is loaded to be able to
