@@ -18,7 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <libglom/libglom_config.h>
+#include "config.h"
 #include "dialog_existing_or_new.h"
 
 #include <libxml++/parsers/saxparser.h>
@@ -100,13 +100,17 @@ Dialog_ExistingOrNew::Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::
   builder->get_widget("existing_or_new_existing_treeview", m_existing_view);
   builder->get_widget("existing_or_new_new_treeview", m_new_view);
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   if(!m_existing_view || !m_new_view)
     throw std::runtime_error("Glade file does not contain treeviews for ExistingOrNew dialog.");
+#endif    
 
   builder->get_widget("existing_or_new_notebook", m_notebook);
   builder->get_widget("existing_or_new_button_select", m_select_button);
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   if(!m_notebook || !m_select_button)
     throw std::runtime_error("Glade file does not contain the notebook or the select button for ExistingOrNew dialog.");
+#endif
 
   m_existing_model = Gtk::TreeStore::create(m_existing_columns);
   m_existing_model->set_sort_column(m_existing_columns.m_col_time, Gtk::SORT_DESCENDING);
@@ -155,25 +159,19 @@ Dialog_ExistingOrNew::Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 
 #ifdef G_OS_WIN32
-  gchar* dir = g_win32_get_package_installation_directory_of_module(NULL);
-  std::string path = Glib::build_filename(dir, "share/glom/doc/examples");
+  gchar* dir = g_win32_get_package_installation_directory_of_module(0);
+  std::string path = Glib::build_filename(dir, "share" G_DIR_SEPARATOR_S "doc"
+                                                       G_DIR_SEPARATOR_S "glom"
+                                                       G_DIR_SEPARATOR_S "examples");
   g_free(dir);
 
   if(!Glib::file_test(path, Glib::FILE_TEST_EXISTS))
-    path = GLOM_EXAMPLES_DIR;
+    path = GLOM_DOCDIR G_DIR_SEPARATOR_S "examples";
 #else
-  const char* path = GLOM_EXAMPLES_DIR;
+  const char *const path = GLOM_DOCDIR G_DIR_SEPARATOR_S "examples";
 #endif //G_OS_WIN32
 
-  if(!list_examples_at_path(path))
-  {
-    // If that directory did not exist, then try this one instead:
-    // (An Ubuntu package puts the example files here for some reason.
-    // TODO: Find out what Makefile.am variable to use to just use this automatically instead.
-    #ifndef G_OS_WIN32
-    list_examples_at_path(GLOM_EXAMPLES_DIR_ALTERNATIVE);
-    #endif //G_OS_WIN32
-  }
+  list_examples_at_path(path);
 
 #endif //!GLOM_ENABLE_CLIENT_ONLY
 
@@ -241,7 +239,7 @@ Dialog_ExistingOrNew::Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 bool Dialog_ExistingOrNew::list_examples_at_path(const std::string& path)
 {
-  std::cout << "Dialog_ExistingOrNew::list_examples_at_path(): path=" << path << std::endl;
+  //std::cout << "Debug: Dialog_ExistingOrNew::list_examples_at_path(): path=" << path << std::endl;
 
   m_examples_dir = Gio::File::create_for_path(path);
 
@@ -366,7 +364,9 @@ Glib::ustring Dialog_ExistingOrNew::get_uri() const
   }
   else
   {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
     throw std::logic_error("Dialog_ExistingOrNew::get_uri: action is neither NEW_FROM_TEMPLATE nor OPEN_URI");
+#endif    
   }
 }
 
@@ -378,8 +378,10 @@ EpcServiceInfo* Dialog_ExistingOrNew::get_service_info() const
 
   if(action == OPEN_REMOTE)
     return (*iter)[m_existing_columns.m_col_service_info];
+#ifdef GLIBMM_EXCEPTIONS_ENABLED    
   else
     throw std::logic_error("Dialog_ExistingOrNew::get_service_info: action is not OPEN_REMOTE");
+#endif    
 }
 
 Glib::ustring Dialog_ExistingOrNew::get_service_name() const
@@ -389,8 +391,10 @@ Glib::ustring Dialog_ExistingOrNew::get_service_name() const
 
   if(action == OPEN_REMOTE)
     return (*iter)[m_existing_columns.m_col_service_name];
+#ifdef GLIBMM_EXCEPTIONS_ENABLED    
   else
     throw std::logic_error("Dialog_ExistingOrNew::get_service_name: action is not OPEN_REMOTE");
+#endif    
 }
 #endif
 
@@ -410,27 +414,56 @@ std::auto_ptr<Gtk::TreeModel::iterator> Dialog_ExistingOrNew::create_dummy_item_
 
 void Dialog_ExistingOrNew::existing_icon_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
-  Gtk::CellRendererPixbuf* pixbuf_renderer = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
-  if(!pixbuf_renderer) throw std::logic_error("Renderer not a pixbuf renderer in existing_icon_data_func");
+  Gtk::CellRendererPixbuf* pixbuf_renderer = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);  
+  if(!pixbuf_renderer) 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+  throw std::logic_error("Renderer not a pixbuf renderer in existing_icon_data_func");
+#else
+  return;
+#endif
 
+#ifdef GLIBMM_PROPERTIES_ENABKED
   pixbuf_renderer->property_stock_size() = Gtk::ICON_SIZE_BUTTON;
   pixbuf_renderer->property_stock_id() = "";
   pixbuf_renderer->property_pixbuf() = Glib::RefPtr<Gdk::Pixbuf>();
 
   if(iter == m_iter_existing_recent)
-    pixbuf_renderer->property_stock_id() = Gtk::Stock::INDEX.id; // TODO: More meaningful icon?
+    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::INDEX); // TODO: More meaningful icon?
 #ifndef G_OS_WIN32
   else if(iter == m_iter_existing_network)
-    pixbuf_renderer->property_stock_id() = Gtk::Stock::NETWORK.id;
+    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::NETWORK);
 #endif
   else if(iter == m_iter_existing_other)
-    pixbuf_renderer->property_stock_id() = Gtk::Stock::OPEN.id;
+    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::OPEN);
   else if(m_iter_existing_recent_dummy.get() != NULL && iter == *m_iter_existing_recent_dummy)
-    pixbuf_renderer->property_stock_id() = Gtk::Stock::DIALOG_ERROR.id; // TODO: Use Stock::STOP instead?
+    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::DIALOG_ERROR); // TODO: Use Stock::STOP instead?
 #ifndef G_OS_WIN32
   else if(m_iter_existing_network_dummy.get() != NULL && iter == *m_iter_existing_network_dummy)
-    pixbuf_renderer->property_stock_id() = Gtk::Stock::DIALOG_ERROR.id; // TODO: Use Stock::STOP instead?
+    pixbuf_renderer->property_stock_id() = Gtk::StockID(Gtk::Stock::DIALOG_ERROR); // TODO: Use Stock::STOP instead?
 #endif
+
+#else // Properties enabled
+
+  pixbuf_renderer->set_property("stock-size", Gtk::ICON_SIZE_BUTTON);
+  pixbuf_renderer->set_property("stock-id", std::string());
+  pixbuf_renderer->set_property("pixbuf", Glib::RefPtr<Gdk::Pixbuf>());
+
+  if(iter == m_iter_existing_recent)
+    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::INDEX));
+#ifndef G_OS_WIN32
+  else if(iter == m_iter_existing_network)
+    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::NETWORK));
+#endif
+  else if(iter == m_iter_existing_other)
+    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::OPEN));
+  else if(m_iter_existing_recent_dummy.get() != NULL && iter == *m_iter_existing_recent_dummy)
+    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::DIALOG_ERROR)); // TODO: Use Stock::STOP instead?
+#ifndef G_OS_WIN32
+  else if(m_iter_existing_network_dummy.get() != NULL && iter == *m_iter_existing_network_dummy)
+    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::DIALOG_ERROR)); // TODO: Use Stock::STOP instead?
+#endif
+
+#endif // Properties enabled
   else
   {
     if(m_existing_model->is_ancestor(m_iter_existing_recent, iter))
@@ -448,7 +481,9 @@ void Dialog_ExistingOrNew::existing_icon_data_func(Gtk::CellRenderer* renderer,
 #endif
     else
     {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
       throw std::logic_error("Unexpected iterator in existing_icon_data_func");
+#endif      
     }
   }
 }
@@ -456,8 +491,14 @@ void Dialog_ExistingOrNew::existing_icon_data_func(Gtk::CellRenderer* renderer,
 void Dialog_ExistingOrNew::existing_title_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
   Gtk::CellRendererText* text_renderer = dynamic_cast<Gtk::CellRendererText*>(renderer);
-  if(!text_renderer) throw std::logic_error("Renderer not a text renderer in existing_title_data_func");
+  if(!text_renderer)
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+ throw std::logic_error("Renderer not a text renderer in existing_title_data_func");
+#else
+  return;
+#endif    
 
+#ifdef GLIBMM_PROPERTIES_ENABLED
   text_renderer->property_text() = (*iter)[m_existing_columns.m_col_title];
 
   // Default: Use default color
@@ -472,13 +513,35 @@ void Dialog_ExistingOrNew::existing_title_data_func(Gtk::CellRenderer* renderer,
   {
     text_renderer->property_foreground() = "grey";
   }
+#else // PROPERTIES_ENABLED
+  Glib::ustring text = (*iter)[m_existing_columns.m_col_title];
+  text_renderer->set_property("text", text);
+  // Default: Use default color
+  text_renderer->set_property("foreground-set", false);
+  // Use grey if parent item has no children
+#ifndef G_OS_WIN32
+  if( (iter == m_iter_existing_network && m_iter_existing_network_dummy.get()) ||
+      (iter == m_iter_existing_recent && m_iter_existing_recent_dummy.get()))
+#else
+  if(iter == m_iter_existing_recent && m_iter_existing_recent_dummy.get())
+#endif
+  {
+    text_renderer->set_property("foreground", std::string("grey"));
+  } 
+#endif // PROPERTIES_ENABLED
 }
 
 void Dialog_ExistingOrNew::new_icon_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
   Gtk::CellRendererPixbuf* pixbuf_renderer = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
-  if(!pixbuf_renderer) throw std::logic_error("Renderer not a pixbuf renderer in new_icon_data_func");
+  if(!pixbuf_renderer)
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+  throw std::logic_error("Renderer not a pixbuf renderer in new_icon_data_func");
+#else
+  return;
+#endif
 
+#ifdef GLIBMM_PROPERTIES_ENABLED
   pixbuf_renderer->property_stock_size() = Gtk::ICON_SIZE_BUTTON;
   pixbuf_renderer->property_stock_id() = "";
   pixbuf_renderer->property_pixbuf() = Glib::RefPtr<Gdk::Pixbuf>();
@@ -497,16 +560,49 @@ void Dialog_ExistingOrNew::new_icon_data_func(Gtk::CellRenderer* renderer, const
     }
     else
     {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED    
       throw std::logic_error("Unexpected iterator in new_icon_data_func");
+#endif      
     }
   }
+#else
+  pixbuf_renderer->set_property("stock-size", Gtk::ICON_SIZE_BUTTON);
+  pixbuf_renderer->set_property("stock-id", Glib::ustring());
+  pixbuf_renderer->set_property("pixbuf", Glib::RefPtr<Gdk::Pixbuf>());
+      
+  if(iter == m_iter_new_empty)
+    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::NEW));
+  else if(iter == m_iter_new_template)
+    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::EDIT)); // TODO: More meaningful icon?
+  else if(m_iter_new_template_dummy.get() != NULL && iter == *m_iter_new_template_dummy)
+    pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::DIALOG_ERROR)); // TODO: Use Stock::STOP instead?
+  else
+  {
+    if(m_new_model->is_ancestor(m_iter_new_template, iter))
+    {
+      pixbuf_renderer->set_property("icon-name", Glib::ustring("glom"));
+    }
+    else
+    {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED    
+      throw std::logic_error("Unexpected iterator in new_icon_data_func");
+#endif      
+    }
+  }
+#endif 
 }
 
 void Dialog_ExistingOrNew::new_title_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
   Gtk::CellRendererText* text_renderer = dynamic_cast<Gtk::CellRendererText*>(renderer);
-  if(!text_renderer) throw std::logic_error("Renderer not a text renderer in new_title_data_func");
+  if(!text_renderer) 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+    throw std::logic_error("Renderer not a text renderer in new_title_data_func");
+#else
+    return;
+#endif    
 
+#ifdef GLIBMM_PROPERTIES_ENABLED
   text_renderer->property_text() = (*iter)[m_new_columns.m_col_title];
 
   // Default: Use default color
@@ -516,6 +612,18 @@ void Dialog_ExistingOrNew::new_title_data_func(Gtk::CellRenderer* renderer, cons
   {
     text_renderer->property_foreground() = "grey";
   }
+#else
+  Glib::ustring text = (*iter)[m_new_columns.m_col_title];
+  text_renderer->set_property("text", text);
+
+  // Default: Use default color
+  text_renderer->set_property("foreground-set", false);
+  // Use grey if parent item has no children
+  if( (iter == m_iter_new_template && m_iter_new_template_dummy.get()))
+  {
+    text_renderer->set_property("foreground", Glib::ustring("grey"));
+  }
+#endif    
 }
 
 void Dialog_ExistingOrNew::on_switch_page(GtkNotebookPage* /* page */, guint /* page_num */)
