@@ -21,7 +21,7 @@
 #ifndef DIALOG_GLOM_H
 #define DIALOG_GLOM_H
 
-#include "box_withbuttons.h"
+#include <glom/box_withbuttons.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/button.h>
 
@@ -32,7 +32,7 @@ class Dialog_Glom :
   public Gtk::Dialog
 {
 public: 
-  Dialog_Glom(Box_WithButtons* pBox);
+  Dialog_Glom(Box_WithButtons* pBox, const Glib::ustring& title = Glib::ustring());
   virtual ~Dialog_Glom();
 
   //Signal handlers:
