@@ -25,6 +25,7 @@
 
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/cellrenderercombo.h>
+#include <glom/utils_ui.h>
 #include <glibmm/i18n.h>
 #include <cerrno>
 
@@ -37,46 +38,86 @@ namespace
 {
 
 const gunichar DELIMITER = ',';
+const gunichar QUOTE = '\"';
 
-
-Glib::ustring::const_iterator advance_field(const Glib::ustring::const_iterator& iter, const Glib::ustring::const_iterator& end, Glib::ustring& field)
+static bool next_char_is_quote(const Glib::ustring::const_iterator& iter, const Glib::ustring::const_iterator& end)
 {
-  Glib::ustring::const_iterator walk = iter;
+  if(iter == end)
+    return false;
+  
+  //Look at the next character to see if it's really "" (an escaped "):
+  Glib::ustring::const_iterator iter_next = iter;
+  ++iter_next;
+  if(iter_next != end)
+  {
+    const gunichar c_next = *iter_next;
+    if(c_next == QUOTE)
+    {
+      return true;
+    }
+  }
+  
+  return false;
+}
 
-  gunichar quote_char = 0;
-  bool escaped = false;
+//Parse the field in a comma-separated line, returning the field including the quotes:
+static Glib::ustring::const_iterator advance_field(const Glib::ustring::const_iterator& iter, const Glib::ustring::const_iterator& end, Glib::ustring& field)
+{
+  bool inside_quotes = false;
+  //bool string_finished = false; //Ignore anything after "something", such as "something"else,
 
   field.clear();
 
-  for(; walk != end; ++ walk)
+  Glib::ustring::const_iterator walk;
+  for(walk = iter; walk != end; ++walk)
   {
-    gunichar c = *walk;
+    const gunichar c = *walk;
+    
+    //if(string_finished)
+    //  continue;
 
-    // Skip escape sequences
-    if(escaped)
+    if(inside_quotes)
     {
-      field += c;
-      escaped = false;
+      // End of quoted string?
+      if(c == QUOTE)
+      {
+        if(next_char_is_quote(walk, end))
+        {
+          //This is "" so it's not an end quote. Just add one quote:
+          field += c;
+          ++walk; //Skip the second ".
+        }
+        else
+        {
+          inside_quotes = false;
+          //string_finished = true; //Ignore anything else before the next comma.
+        }
+        
+        continue;
+      }
+    }
+    else
+    {
+      // Start of quoted string:
+      if((c == QUOTE))
+      {
+        inside_quotes = true;
+        continue;
+      }
+      // End of field:
+      else if(!inside_quotes && c == DELIMITER)
+      {
+        break;
+      }
+      
       continue;
     }
 
-    // Escaped stuff in quoted strings:
-    if(quote_char && c == '\\')
-      escaped = true;
-    // End of quoted string
-    else if(quote_char && c == quote_char)
-      quote_char = 0;
-    // Begin of quoted string.
-    else if(!quote_char && (c == '\'' || c == '\"'))
-      quote_char = c;
-    // End of field:
-    else if(!quote_char && c == DELIMITER)
-      break;
-
     field += c; // Just so that we don't need to iterate through the field again, since there is no Glib::ustring::substr(iter, iter)
   }
 
   // TODO: Throw error if still inside a quoted string?
+  std::cout << "debug: field=" << field << std::endl;
   return walk;
 }
 
@@ -161,8 +202,10 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
   builder->get_widget("import_csv_sample_rows", m_sample_rows);
   builder->get_widget("import_csv_advice_label", m_advice_label);
   builder->get_widget("import_csv_error_label", m_error_label);
+#ifdef GLIBMM_EXCEPTIONS_ENABLED  
   if(!m_sample_view || !m_encoding_combo || !m_target_table || !m_encoding_info || !m_first_line_as_title || !m_sample_rows || !m_error_label)
     throw std::runtime_error("Missing widgets from glade file for Dialog_Import_CSV");
+#endif
 
   m_encoding_model = Gtk::ListStore::create(m_encoding_columns);
 
@@ -328,12 +371,10 @@ void Dialog_Import_CSV::clear()
   validate_primary_key();
 }
 
-void Dialog_Import_CSV::show_error_dialog(const Glib::ustring& primary, const Glib::ustring& secondary)
+void Dialog_Import_CSV::show_error_dialog(const Glib::ustring&, const Glib::ustring& secondary)
 {
-  Gtk::MessageDialog dialog(*this, primary, false, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK);
-  dialog.set_title(_("Error Importing CSV File"));
-  dialog.set_secondary_text(secondary);
-  dialog.run();
+  Utils::show_ok_dialog(_("Error Importing CSV File"),
+     secondary, *this, Gtk::MESSAGE_ERROR);
 }
 
 void Dialog_Import_CSV::encoding_data_func(const Gtk::TreeModel::iterator& iter, Gtk::CellRendererText& renderer)
@@ -351,6 +392,7 @@ bool Dialog_Import_CSV::row_separator_func(const Glib::RefPtr<Gtk::TreeModel>& /
 
 void Dialog_Import_CSV::on_query_info(const Glib::RefPtr<Gio::AsyncResult>& result)
 {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     Glib::RefPtr<Gio::FileInfo> info = m_file->query_info_finish(result);
@@ -361,10 +403,22 @@ void Dialog_Import_CSV::on_query_info(const Glib::RefPtr<Gio::AsyncResult>& resu
   {
     std::cerr << "Failed to fetch display name of uri " << m_file->get_uri() << ": " << ex.what() << std::endl;
   }
+#else
+  std::auto_ptr<Glib::Error> error;
+  Glib::RefPtr<Gio::FileInfo> info = m_file->query_info_finish(result, error);
+  if (!error.get())
+  {
+    m_filename = info->get_display_name();
+    set_title(m_filename + _(" - Import From CSV File"));
+  }
+  else
+    std::cerr << "Failed to fetch display name of uri " << m_file->get_uri() << ": " << error->what() << std::endl;
+#endif    
 }
 
 void Dialog_Import_CSV::on_file_read(const Glib::RefPtr<Gio::AsyncResult>& result)
 {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     m_stream = m_file->read_finish(result);
@@ -378,10 +432,25 @@ void Dialog_Import_CSV::on_file_read(const Glib::RefPtr<Gio::AsyncResult>& resul
     clear();
     // TODO: Response?
   }
+#else
+    std::auto_ptr<Glib::Error> error;
+    m_stream = m_file->read_finish(result, error);
+    if (!error.get())
+    {
+      m_buffer.reset(new Buffer);
+      m_stream->read_async(m_buffer->buf, sizeof(m_buffer->buf), sigc::mem_fun(*this, &Dialog_Import_CSV::on_stream_read));
+    }
+    else
+    {
+      show_error_dialog(_("Could Not Open file"), Glib::ustring::compose(_("The file at \"%1\" could not be opened: %2"), m_file->get_uri(), error->what()));
+      clear();
+    }
+#endif    
 }
 
 void Dialog_Import_CSV::on_stream_read(const Glib::RefPtr<Gio::AsyncResult>& result)
 {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     const gssize size = m_stream->read_finish(result);
@@ -420,6 +489,46 @@ void Dialog_Import_CSV::on_stream_read(const Glib::RefPtr<Gio::AsyncResult>& res
     clear();
     // TODO: Response?
   }
+#else
+    std::auto_ptr<Glib::Error> error;
+    const gssize size = m_stream->read_finish(result, error);
+    if (!error.get())
+    {
+      m_raw.insert(m_raw.end(), m_buffer->buf, m_buffer->buf + size);
+
+      // If the parser already exists, but it is currently not parsing because it waits
+      // for new input, then continue parsing.
+      if(m_parser.get() && !m_parser->idle_connection.connected())
+      {
+        m_parser->idle_connection = Glib::signal_idle().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_idle_parse));
+      }
+      // If the parser does not exist yet, then create a new parser, except when the
+      // current encoding does not work for the file ,in which case the user must first
+      // choose another encoding.
+      else if(!m_parser.get() && m_state != ENCODING_ERROR)
+      {
+        begin_parse();
+      }
+
+      if(size > 0)
+      {
+        // Read the next few bytes
+        m_stream->read_async(m_buffer->buf, sizeof(m_buffer->buf), sigc::mem_fun(*this, &Dialog_Import_CSV::on_stream_read));
+      }
+      else
+      {
+        // Finished reading
+        m_buffer.reset(NULL);
+        m_stream.reset();
+        m_file.reset();
+      }
+    }
+    if (error.get())
+    {
+      show_error_dialog(_("Could Not Read File"), Glib::ustring::compose(_("The file at \"%1\" could not be read: %2"), m_file->get_uri(), error->what()));
+      clear();
+    }
+#endif
 }
 
 void Dialog_Import_CSV::on_encoding_changed()
@@ -613,7 +722,7 @@ void Dialog_Import_CSV::encoding_error()
 
 bool Dialog_Import_CSV::on_idle_parse()
 {
-  // The amount of bytes to process in one pass of the idle handler
+  // The amount of bytes to process in one pass of the idle handler:
   static const guint CONVERT_BUFFER_SIZE = 1024;
 
   const char* inbuffer = &m_raw[m_parser->input_position];
@@ -657,25 +766,67 @@ bool Dialog_Import_CSV::on_idle_parse()
   m_parser->input_position += (inbuf - inbuffer);
 
   // We now have outbuf - outbuffer bytes of valid UTF-8 in outbuffer.
-  const char* prev = outbuffer;
-  const char* pos;
-  const char to_find[] = { '\r', '\n', '\0' };
+  const char* prev_line_end = outbuffer;
+  const char* prev = prev_line_end;
 
-  while( (pos = std::find_first_of<const char*>(prev, outbuf, to_find, to_find + sizeof(to_find))) != outbuf)
+  //Identify the record rows in the .cvs file.
+  //We can't just search for newlines because they may be inside quotes too. 
+  //TODO: Use a regex instead, to more easily handle quotes?
+  bool in_quotes = false;
+  while(true)
   {
-    if(*pos == '\0')
+    //Note that, unlike std::string::find*, std::find* returns an iterator (char*), not a position.
+    //It returns outbuf if none is found.
+    const char newline_to_find[] = { '\r', '\n', '\0' };
+    const char* pos_newline = std::find_first_of<const char*>(prev, outbuf, newline_to_find, newline_to_find + sizeof(newline_to_find));
+    
+    const char quote_to_find[] = {(char)QUOTE};
+    const char* pos_quote = std::find_first_of<const char*>(prev, outbuf, quote_to_find, quote_to_find + sizeof(quote_to_find));
+    
+    //Examine the first character (quote or newline) that was found:
+    const char* pos = pos_newline;
+    if((pos_quote != outbuf) && pos_quote < pos)
+      pos = pos_quote;
+      
+    if(pos == outbuf)
+      break;
+    
+    char ch = *pos;   
+    
+    if(ch == '\0')
     {
-      // There is a nullbyte in the conversion. As normal text files don't
-      // contain nullbytes, this only occurs when converting for example a UTF-16
-      // file from ISO-8859-1 to UTF-8 (note that the UTF-16 file is valid ISO-8859-1,
+      // There is a null byte in the conversion. Because normal text files don't
+      // contain null bytes this only occurs when converting, for example, a UTF-16
+      // file from ISO-8859-1 to UTF-8 (note that the UTF-16 file is valid ISO-8859-1 - 
       // it just contains lots of nullbytes). We therefore produce an error here.
       encoding_error();
       return false;
     }
+    else if(in_quotes)
+    {
+      //Ignore newlines inside quotes.
+      
+      //End quote:
+      if(ch == (char)QUOTE)
+        in_quotes = false;
+        
+      prev = pos + 1;
+      continue;
+    }
     else
     {
-      m_parser->current_line.append(prev, pos - prev);
-      ++ m_parser->line_number;
+      //Start quote:
+      if(ch == (char)QUOTE)
+      {
+        in_quotes = true;
+        prev = pos + 1;
+        continue;
+      }
+    
+      //Found a newline (outside of quotes) that marks the end of the line:
+      m_parser->current_line.append(prev_line_end, pos - prev_line_end);
+      ++(m_parser->line_number);
+      
       if(!m_parser->current_line.empty())
         handle_line(m_parser->current_line, m_parser->line_number);
 
@@ -685,7 +836,13 @@ bool Dialog_Import_CSV::on_idle_parse()
       prev = pos + 1;
 
       // Skip DOS-style linebreak (\r\n)
-      if(*pos == '\r' && prev != outbuf && *prev == '\n') ++ prev;
+      if(ch == '\r' 
+         && prev != outbuf && *prev == '\n')
+      {
+         ++prev;
+      }
+      
+      prev_line_end = prev;
     }
   }
 
@@ -693,7 +850,8 @@ bool Dialog_Import_CSV::on_idle_parse()
   m_parser->current_line.append(prev, outbuf - prev);
   if(!m_stream && m_raw.size() == m_parser->input_position)
   {
-    ++ m_parser->line_number;
+    ++(m_parser->line_number);
+    
     // Handle last line, if nonempty
     if(m_parser->current_line.empty())
       handle_line(m_parser->current_line, m_parser->line_number);
@@ -709,10 +867,12 @@ bool Dialog_Import_CSV::on_idle_parse()
 
 void Dialog_Import_CSV::handle_line(const Glib::ustring& line, guint line_number)
 {
-  if(line.empty()) return;
+  std::cout << "debug: handle_line=" << line << std::endl;
+  if(line.empty())
+   return;
 
-  m_rows.push_back(std::vector<Glib::ustring>());
-  std::vector<Glib::ustring>& row = m_rows.back();
+  m_rows.push_back(type_row_strings());
+  type_row_strings& row = m_rows.back();
 
   Glib::ustring field;
   //Gtk::TreeModelColumnRecord record;
@@ -757,9 +917,15 @@ void Dialog_Import_CSV::handle_line(const Glib::ustring& line, guint line_number
       col->pack_start(*cell, true);
       col->set_cell_data_func(*cell, sigc::bind(sigc::mem_fun(*this, &Dialog_Import_CSV::field_data_func), i));
       col->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
+#ifdef GLIBMM_PROPERTIES_ENABLED      
       cell->property_model() = m_field_model_sorted;
       cell->property_text_column() = 0;
       cell->property_has_entry() = false;
+#else      
+      cell->set_property("model", m_field_model_sorted);
+      cell->set_property("text-column", 0);
+      cell->set_property("has_entry", false);
+#endif
       cell->signal_edited().connect(sigc::bind(sigc::mem_fun(*this, &Dialog_Import_CSV::on_field_edited), i));
       m_sample_view->append_column(*col);
     }
@@ -787,10 +953,12 @@ void Dialog_Import_CSV::handle_line(const Glib::ustring& line, guint line_number
 
 void Dialog_Import_CSV::line_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
-  int row = (*iter)[m_sample_columns.m_col_row];
+  const int row = (*iter)[m_sample_columns.m_col_row];
   Gtk::CellRendererText* renderer_text = dynamic_cast<Gtk::CellRendererText*>(renderer);
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   if(!renderer_text)
     throw std::logic_error("CellRenderer is not a CellRendererText in line_data_func");
+#endif    
 
   if(row == -1)
     renderer_text->set_property("text", Glib::ustring(_("Target Field")));
@@ -802,64 +970,82 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
 {
   const int row = (*iter)[m_sample_columns.m_col_row];
   Gtk::CellRendererCombo* renderer_combo = dynamic_cast<Gtk::CellRendererCombo*>(renderer);
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   if(!renderer_combo) throw std::logic_error("CellRenderer is not a CellRendererCombo in field_data_func");
+#endif  
 
+  Glib::ustring text;
+  bool editable = false;
+  
   if(row == -1)
   {
     sharedptr<Field> field = m_fields[column_number];
     if(field)
-      renderer_combo->set_property("text", field->get_name());
+      text = field->get_name();
     else
-      renderer_combo->set_property("text", Glib::ustring("<None>"));
+      text = _("<None>");
 
-    renderer_combo->set_property("editable", true);
+    editable = true;
   }
   else
   {
     // Convert to currently chosen field, if any, and back, too see how it
-    // looks like when imported
-    sharedptr<Field> field = m_fields[column_number];
-    const Glib::ustring& orig_text = m_rows[row][column_number];
-
-    Glib::ustring text;
-    if(field)
+    // looks like when imported:
+    
+    if(column_number < m_fields.size())
     {
-      bool success;
-
-      if(field->get_glom_type() != Field::TYPE_IMAGE)
+      sharedptr<Field> field = m_fields[column_number];
+ 
+      if(row != -1 && (unsigned int)row < m_rows.size())
       {
-        /* Exported data is always stored in postgres format */
-        const Gnome::Gda::Value value = field->from_file_format(orig_text, success);
+        const type_row_strings& row_strings = m_rows[row];
+        if(column_number < row_strings.size())
+        {
+      
+          const Glib::ustring& orig_text = row_strings[column_number];
+
+          if(field)
+          {
+            if(field->get_glom_type() != Field::TYPE_IMAGE)
+            {
+              /* Exported data is always stored in postgres format */
+              bool success = false;
+              const Gnome::Gda::Value value = field->from_file_format(orig_text, success);
         
-        if(!success)
-          text = _("<Import Failure>");
-        else
-          text = Glom::Conversions::get_text_for_gda_value(field->get_glom_type(), value);
-      }
-      else
-      {
-        // TODO: It is too slow to create the picture here. Maybe we should
-        // create it once and cache it. We could also think about using a
-        // GtkCellRendererPixbuf to show it, then.
-        if(!orig_text.empty() && orig_text != "NULL")
-          text = _("<Picture>");
+              if(!success)
+                text = _("<Import Failure>");
+              else
+                text = Glom::Conversions::get_text_for_gda_value(field->get_glom_type(), value);
+            }
+            else
+            {
+              // TODO: It is too slow to create the picture here. Maybe we should
+              // create it once and cache it. We could also think about using a
+              // GtkCellRendererPixbuf to show it, then.
+              if(!orig_text.empty() && orig_text != "NULL")
+                text = _("<Picture>");
+            }
+          }
+          else
+          {
+            // TODO: Should we unescape the field's content?
+            text = orig_text;
+          }
+
+          if(text.length() > 32)
+          {
+            text.erase(32);
+            text.append("…");
+          }
+
+          editable = false;
+        }
       }
     }
-    else
-    {
-      // TODO: Should we unescape the field's content?
-      text = orig_text;
-    }
-
-    if(text.length() > 32)
-    {
-      text.erase(32);
-      text.append("…");
-    }
-
-    renderer_combo->set_property("text", text);
-    renderer_combo->set_property("editable", false);
   }
+  
+  renderer_combo->set_property("text", text);
+  renderer_combo->set_property("editable", editable);
 }
 
 void Dialog_Import_CSV::on_field_edited(const Glib::ustring& path, const Glib::ustring& new_text, guint column_number)
