@@ -18,15 +18,14 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_MAEMO
+#include "config.h" // For GLOM_ENABLE_MAEMO
 
 #include "box_data.h"
 #include <libglom/data_structure/glomconversions.h>
-#include <libglom/utils.h>
+#include <glom/utils_ui.h>
 #include <libglom/data_structure/layout/layoutitem_field.h>
 #include <glom/glom_privs.h>
-#include "../python_embed/glom_python.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <glom/python_embed/glom_python.h>
 #include <algorithm> //For std::find()
 #include <libglom/libglom_config.h>
 #include <glibmm/i18n.h>
@@ -140,7 +139,7 @@ void Box_Data::on_Button_Find()
 #ifdef GLOM_ENABLE_MAEMO
     Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, *get_app_window(), message);
 #else
-    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("No Find Criteria")), true, Gtk::MESSAGE_WARNING );
+    Gtk::MessageDialog dialog(Utils::bold_message(_("No Find Criteria")), true, Gtk::MESSAGE_WARNING );
     dialog.set_secondary_text(message);
     dialog.set_transient_for(*get_app_window());
 #endif
@@ -185,7 +184,7 @@ bool Box_Data::confirm_discard_unstored_data() const
     //Hildon::Note dialog(Hildon::NOTE_TYPE_CONFIRMATION, *get_app_window(), message);
     Hildon::Note dialog(Hildon::NOTE_TYPE_CONFIRMATION, message);
 #else
-    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("No primary key value")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+    Gtk::MessageDialog dialog(Utils::bold_message(_("No primary key value")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
     dialog.set_secondary_text(message);
 #endif
     //TODO: It needs a const. I wonder if it should. murrayc. dialog.set_transient_for(*get_app_window());
@@ -237,21 +236,21 @@ Box_Data::type_vecLayoutFields Box_Data::get_fields_to_show() const
 
 Box_Data::type_vecLayoutFields Box_Data::get_table_fields_to_show(const Glib::ustring& table_name) const
 {
-  const Document_Glom* pDoc = dynamic_cast<const Document_Glom*>(get_document());
+  const Document* pDoc = dynamic_cast<const Document*>(get_document());
   if(pDoc)
   {
-    Document_Glom::type_list_layout_groups mapGroupSequence = pDoc->get_data_layout_groups_plus_new_fields(m_layout_name, table_name, m_layout_platform);
+    Document::type_list_layout_groups mapGroupSequence = pDoc->get_data_layout_groups_plus_new_fields(m_layout_name, table_name, m_layout_platform);
     return get_table_fields_to_show_for_sequence(table_name, mapGroupSequence);
   }
   else
     return type_vecLayoutFields();
 }
 
-Document_Glom::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& layout_platform)
+Document::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::ustring& layout_name, const Glib::ustring& layout_platform)
 {
-  Document_Glom::type_list_layout_groups layout_groups;
+  Document::type_list_layout_groups layout_groups;
 
-  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+  Document* document = dynamic_cast<Document*>(get_document());
   if(document)
   {
     if(!m_table_name.empty())
@@ -262,7 +261,7 @@ Document_Glom::type_list_layout_groups Box_Data::get_data_layout_groups(const Gl
       const Privileges table_privs = Privs::get_current_privs(m_table_name);
 
       //Fill in the field information for the fields mentioned in the layout:
-      for(Document_Glom::type_list_layout_groups::iterator iterGroups = layout_groups.begin(); iterGroups != layout_groups.end(); ++iterGroups)
+      for(Document::type_list_layout_groups::iterator iterGroups = layout_groups.begin(); iterGroups != layout_groups.end(); ++iterGroups)
       {
         fill_layout_group_field_info(*iterGroups, table_privs);
 
@@ -280,7 +279,7 @@ void Box_Data::fill_layout_group_field_info(const sharedptr<LayoutGroup>& group,
   if(!group)
    return;
 
-  const Document_Glom* document = get_document();
+  const Document* document = get_document();
 
   LayoutGroup::type_list_items items = group->get_items();
   for(LayoutGroup::type_list_items::iterator iter = items.begin(); iter != items.end(); ++iter)
