@@ -21,7 +21,7 @@
 #ifndef GLOM_UTILITYWIDGETS_FLOWTABLEWITHFIELDS_H
 #define GLOM_UTILITYWIDGETS_FLOWTABLEWITHFIELDS_H
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 #ifdef GLOM_ENABLE_CLIENT_ONLY
 #include <glom/utility_widgets/flowtable.h>
@@ -42,7 +42,7 @@
 #include <glom/utility_widgets/layoutwidgetutils.h>
 #include <glom/mode_data/box_data_list_related.h>
 #include "box_data_calendar_related.h"
-#include "treestore_layout.h" //Forthe enum.
+#include <glom/mode_design/layout/treestore_layout.h> //Forthe enum.
 #include <map>
 #include <list>
 
