@@ -31,10 +31,10 @@ class Box_DB_Table_Definition : public Box_DB_Table
 {
 public: 
   Box_DB_Table_Definition();
-  Box_DB_Table_Definition(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Box_DB_Table_Definition(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Box_DB_Table_Definition();
 
-protected:
+private:
   void init(); //Avoid duplicating code in constructors.
   virtual bool fill_from_database();
   virtual void fill_fields();
@@ -64,7 +64,7 @@ protected:
 
   Dialog_FieldDefinition* m_pDialog;
   sharedptr<const Field> m_Field_BeingEdited; //TODO_FieldShared
-  type_vecFields m_vecFields;
+  type_vec_fields m_vecFields;
 };
 
 } //namespace Glom
