@@ -19,28 +19,28 @@
  */
 
 #include "box_print_layouts.h"
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <libglom/utils.h> //For bold_message()).
 #include <glibmm/i18n.h>
 
 namespace Glom
 {
 
-Box_Print_Layouts::Box_Print_Layouts(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-: Box_DB_Table(cobject, refGlade),
+Box_Print_Layouts::Box_Print_Layouts(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+: Box_DB_Table(cobject, builder),
   m_pLabelFrameTitle(0),
   m_colName(0),
   m_colTitle(0)
 {
   //Get the Glade-instantiated widgets, and connect signal handlers:
   Gtk::Button* pButtonCancel = 0;
-  refGlade->get_widget("button_cancel", pButtonCancel);
+  builder->get_widget("button_cancel", pButtonCancel);
   set_button_cancel(*pButtonCancel);
 
   Gtk::Alignment* pAligmentPlaceholder = 0;
-  refGlade->get_widget("alignment_placeholder_adddel", pAligmentPlaceholder);
+  builder->get_widget("alignment_placeholder_adddel", pAligmentPlaceholder);
   pAligmentPlaceholder->add(m_AddDel);
 
-  //refGlade->get_widget("label_frame_title", m_pLabelFrameTitle);
+  //builder->get_widget("label_frame_title", m_pLabelFrameTitle);
 
   m_AddDel.signal_user_added().connect(sigc::mem_fun(*this, &Box_Print_Layouts::on_adddel_user_added));
   m_AddDel.signal_user_requested_delete().connect(sigc::mem_fun(*this, &Box_Print_Layouts::on_adddel_user_requested_delete));
@@ -67,7 +67,7 @@ void Box_Print_Layouts::fill_row(const Gtk::TreeModel::iterator& iter, const sha
 
 bool Box_Print_Layouts::fill_from_database()
 {
-  Bakery::BusyCursor busy_cursor(get_app_window());
+  BusyCursor busy_cursor(get_app_window());
 
   bool result = Base_DB::fill_from_database();
 
@@ -97,12 +97,12 @@ bool Box_Print_Layouts::fill_from_database()
   //Glib::ustring strTitle = Glib::ustring("<b>") + _("Tables from Database: ") + get_database_name() + "");
   //m_pLabelFrameTitle->set_markup(strTitle);
 
-  Document_Glom::type_listPrintLayouts listItems;
-  Document_Glom* document = get_document();
+  Document::type_listPrintLayouts listItems;
+  Document* document = get_document();
   if(document)
   {
     listItems = document->get_print_layout_names(m_table_name);
-    for(Document_Glom::type_listPrintLayouts::const_iterator iter = listItems.begin(); iter != listItems.end(); ++iter)
+    for(Document::type_listPrintLayouts::const_iterator iter = listItems.begin(); iter != listItems.end(); ++iter)
     {
       sharedptr<PrintLayout> item = document->get_print_layout(m_table_name, *iter);
       if(item)
@@ -161,7 +161,7 @@ void Box_Print_Layouts::on_adddel_user_requested_edit(const Gtk::TreeModel::iter
 {
   Glib::ustring name = m_AddDel.get_value_key(row);
 
-  Document_Glom* document = get_document();
+  Document* document = get_document();
   if(document)
   {
      save_to_document();
@@ -176,7 +176,7 @@ void Box_Print_Layouts::save_to_document()
   if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     //Add any that are not in the document:
-    Document_Glom::type_listPrintLayouts listItems = get_document()->get_print_layout_names(m_table_name);
+    Document::type_listPrintLayouts listItems = get_document()->get_print_layout_names(m_table_name);
 
     bool modified = false;
     for(Gtk::TreeModel::iterator iter = m_AddDel.get_model()->children().begin(); iter != m_AddDel.get_model()->children().end(); ++iter)
@@ -205,7 +205,7 @@ void Box_Print_Layouts::on_adddel_user_changed(const Gtk::TreeModel::iterator& r
   if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     const Glib::ustring name = m_AddDel.get_value_key(row);
-    Document_Glom* document = get_document();
+    Document* document = get_document();
 
     sharedptr<PrintLayout> item = document->get_print_layout(m_table_name, name);
     if(item)
