@@ -18,9 +18,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 //We need to include this before anything else, to avoid redefinitions:
-#include <glom/libglom/python_embed/py_glom_record.h>
-#include <glom/libglom/python_embed/pygdavalue_conversions.h>
+#include <libglom/python_embed/py_glom_record.h>
+#include <libglom/python_embed/pygdavalue_conversions.h>
 
 #define NO_IMPORT_PYGTK //To avoid a multiple definition in pygtk.
 #include <pygtk/pygtk.h> //For the PyGObject and PyGBoxed struct definitions.
@@ -30,7 +31,7 @@
 #include <eval.h> /* for PyEval_EvalCode */
 
 #include "glom_python.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 #include <list>
 #include <glib.h> //For g_warning().
 #include <glibmm/i18n.h>
@@ -136,13 +137,27 @@ void ShowTrace()
   g_free(chrRetval);
 }
 
-void glom_execute_python_function_implementation(const Glib::ustring& func_impl, const type_map_fields& field_values, Document_Glom* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
+bool glom_python_module_is_available()
+{
+  PyObject* module_glom = PyImport_ImportModule((char*)"glom_" GLOM_ABI_VERSION_UNDERLINED); //TODO: unref this?
+  return module_glom != 0;
+}
+
+bool gda_python_module_is_available()
+{
+  PyObject* module_glom = PyImport_ImportModule((char*)"gda"); //TODO: unref this?
+  return module_glom != 0;
+}
+
+
+
+void glom_execute_python_function_implementation(const Glib::ustring& func_impl, const type_map_fields& field_values, Document* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
 {
   glom_evaluate_python_function_implementation(Field::TYPE_TEXT, func_impl, field_values, pDocument, table_name, opened_connection);
 }
 
 Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field_type result_type, const Glib::ustring& func_impl,
-    const type_map_fields& field_values, Document_Glom* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
+    const type_map_fields& field_values, Document* pDocument, const Glib::ustring& table_name, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
 {
   //std::cout << "glom_evaluate_python_function_implementation()" << std::endl;
   //for(type_map_fields::const_iterator iter = field_values.begin(); iter != field_values.end(); ++iter)
@@ -169,7 +184,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
 
   //prefix the def line:
   const Glib::ustring func_name = "glom_calc_field_value";
-  func_def = "def " + func_name + "(record):\n  import glom\n  import gda\n" + func_def;
+  func_def = "def " + func_name + "(record):\n  import glom_" GLOM_ABI_VERSION_UNDERLINED "\n  import gda\n" + func_def;
   //We did this in main(): Py_Initialize();
 
   PyObject* pMain = PyImport_AddModule((char*)"__main__");
@@ -204,7 +219,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
   }
 
 
-  PyObject* module_glom = PyImport_ImportModule((char*)"glom");
+  PyObject* module_glom = PyImport_ImportModule((char*)"glom_" GLOM_ABI_VERSION_UNDERLINED);
   if(!module_glom)
   {
     g_warning("Could not import python glom module.");
@@ -296,8 +311,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
         //Deal with the various possible return types:
         bool object_is_gda_value = false;
 
-        GValue value;
-        memset(&value, 0, sizeof(GValue));
+        GValue value = {0, {{0}}};
         const int test = pygda_value_from_pyobject(&value, pyResult);
 
         if(test == 0) //-1 means error.
