@@ -18,6 +18,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
 #include "datawidget.h"
 #include "entryglom.h"
 #include "checkglom.h"
@@ -28,10 +29,10 @@
 #include "imageglom.h"
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/application.h>
-#include "../mode_data/dialog_choose_field.h"
+#include <glom/mode_design/layout/dialog_choose_field.h>
 #include "dialog_choose_id.h"
 #include "dialog_choose_date.h"
-#include "../layout_item_dialogs/dialog_field_layout.h"
+#include <glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h>
 #include <glom/utils_ui.h>
 #include <glom/glade_utils.h>
 #include <glibmm/i18n.h>
@@ -589,7 +590,6 @@ bool DataWidget::on_button_press_event(GdkEventButton *event)
 
   return Gtk::EventBox::on_button_press_event(event);
 }
-#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name)
 {
@@ -598,7 +598,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
 
 sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field)
 {
-  return offer_field_list (table_name, start_field, get_document(), get_application());
+  return offer_field_list(table_name, start_field, get_document(), get_application());
 }
 
 sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document* document, App_Glom* app)
@@ -618,13 +618,13 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
     return result;
   }
 #else
-  std::auto_ptr<Gtk::BuilderError> error;
-  refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_field", "", error);
-  if(error.get())
+  std::auto_ptr<Glib::Error> error;
+  refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_field", error);
+  if (error.get())
   {
     std::cerr << error->what() << std::endl;
     return result;
-  }
+  }  
 #endif
   
   Dialog_ChooseField* dialog = 0;
@@ -648,7 +648,6 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
   return result;
 }
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
 sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const LayoutItem_Field>& start_field)
 {
   sharedptr<LayoutItem_Field> result;
@@ -684,16 +683,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const
 
   return result;
 }
-#endif // !GLOM_ENABLE_CLIENT_ONLY
 
-/*
-void DataWidget::on_menupopup_add_item(LayoutWidgetBase::enumType item)
-{
-  signal_layout_item_added().emit(item);
-}
-*/
-
-#ifndef GLOM_ENABLE_CLIENT_ONLY
 void DataWidget::on_menupopup_activate_layout()
 {
   //finish_editing();
@@ -800,13 +790,13 @@ void DataWidget::on_button_choose_date()
     return;
   }
 #else
-  std::auto_ptr<Gtk::BuilderError> error;
-  refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_date", "", error);
-  if(error.get())
+  std::auto_ptr<Glib::Error> error;
+  refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_choose_date", error);
+  if (error.get())
   {
     std::cerr << error->what() << std::endl;
     return;
-  }
+  } 
 #endif
 
   Dialog_ChooseDate* dialog = 0;
@@ -858,8 +848,8 @@ bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
   }
 #else
   std::auto_ptr<Glib::Error> error;
-  refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_find_id", "", error);
-  if(error.get())
+  refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_find_id", error);
+  if (error.get())
   {
     std::cerr << error->what() << std::endl;
     return result;
@@ -887,7 +877,7 @@ bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
     else
       g_warning("get_layout_item() was not a LayoutItem_Field");
 
-    dialog->init_db_details(related_table_name, get_document()->get_active_layout_platform());
+    dialog->init_db_details(related_table_name, Base_DB::get_active_layout_platform(get_document()));
 
 
     const int response = dialog->run();
