@@ -90,6 +90,12 @@ DbAddDel::DbAddDel()
   //set_columns_count(1);
   //construct_specified_columns();
   
+  // Give the TreeView an accessible name, to access it in LDTP
+  // TODO: Maybe this should be a constructor parameter, so that multiple
+  // DbAddDels in a single Window can be addressed separately.
+#ifndef GLOM_ENABLE_MAEMO
+  m_TreeView.get_accessible()->set_name(_("Table Content"));
+#endif  
 
   m_ScrolledWindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
   m_ScrolledWindow.add(m_TreeView);
@@ -652,7 +658,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
        if(pixbuf)
          pixbuf_renderer->set_property("pixbuf", pixbuf);
        else
-         pixbuf_renderer->set_property("stock-id", Gtk::Stock::MISSING_IMAGE);
+         pixbuf_renderer->set_property("stock-id", Gtk::StockID(Gtk::Stock::MISSING_IMAGE));
 
        pCellRenderer = pixbuf_renderer;
      }
@@ -809,15 +815,27 @@ void DbAddDel::apply_formatting(Gtk::CellRenderer* renderer, const FieldFormatti
   //Use the text formatting:
   const Glib::ustring font_desc = formatting.get_text_format_font();
   if(!font_desc.empty())
+#ifdef GLIBMM_PROPERTIES_ENABLED  
     text_renderer->property_font() = font_desc;
+#else
+    text_renderer->set_property("font", font_desc);
+#endif        
 
   const Glib::ustring fg = formatting.get_text_format_color_foreground();
   if(!fg.empty())
+#ifdef GLIBMM_PROPERTIES_ENABLED  
     text_renderer->property_foreground() = fg;
-
+#else    
+    text_renderer->set_property("foreground", fg);
+#endif
+    
   const Glib::ustring bg = formatting.get_text_format_color_background();
   if(!bg.empty())
+#ifdef GLIBMM_PROPERTIES_ENABLED
     text_renderer->property_background() = bg;
+#else    
+    text_renderer->set_property("background", bg);
+#endif
 }
 
 void DbAddDel::construct_specified_columns()
@@ -931,14 +949,13 @@ void DbAddDel::construct_specified_columns()
     m_treeviewcolumn_button = Gtk::manage(new Gtk::TreeViewColumn());
     m_treeviewcolumn_button->pack_start(*pCellButton);
 
-
     int x_offset = 0;
     int y_offset = 0;
     int width = 0;
     int height = 0;
     pCellButton->get_size(m_TreeView, x_offset, y_offset, width, height);
 
-    m_treeviewcolumn_button->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED); //Need by fixed-height mode.
+    m_treeviewcolumn_button->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED); //Needed by fixed-height mode.
 
     // TODO: I am not sure whether this is always correct. Perhaps, we also
     // have to take into account the xpad property of the cell renderer and
@@ -947,7 +964,7 @@ void DbAddDel::construct_specified_columns()
     m_TreeView.get_style_property("horizontal-separator", horizontal_separator);
     m_treeviewcolumn_button->set_fixed_width(width + horizontal_separator*2);
 
-    m_treeviewcolumn_button->set_property("visible", true);
+    m_treeviewcolumn_button->set_visible(m_allow_view_details);
 
     m_TreeView.append_column(*m_treeviewcolumn_button);
 
@@ -2054,9 +2071,10 @@ void DbAddDel::set_allow_view_details(bool val)
 {
   m_allow_view_details = val;
 
-  //Hide it if it was visible:
+  //Hide it if it was visible, if it exists,
+  //otherwise do that later after creating it:
   if(m_treeviewcolumn_button)
-    g_object_set(m_treeviewcolumn_button->gobj(), "visible", get_allow_view_details() ? TRUE : FALSE, (gpointer)NULL);
+    m_treeviewcolumn_button->set_visible(val);
 }
 
 bool DbAddDel::get_allow_view_details() const
@@ -2364,7 +2382,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
     sharedptr<SharedConnection> sharedconnection = connect_to_server(get_application()); //Keep it alive while we need the data_model.
 #else
     std::auto_ptr<ExceptionConnection> error;
-    sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window(), error); //Keep it alive while we need the data_model.
+    sharedptr<SharedConnection> sharedconnection = connect_to_server(get_application(), error); //Keep it alive while we need the data_model.
     // Ignore error - sharedconnection is checked for NULL instead:
 #endif
     if(sharedconnection)
