@@ -77,6 +77,13 @@ ImageGlom::~ImageGlom()
 {
 }
 
+void ImageGlom::set_layout_item(const sharedptr<LayoutItem>& layout_item, const Glib::ustring& table_name)
+{
+  LayoutWidgetField::set_layout_item(layout_item, table_name);
+#ifndef GLOM_ENABLE_MAEMO  
+  get_accessible()->set_name(layout_item->get_name());
+#endif  
+}
 
 bool ImageGlom::on_button_press_event(GdkEventButton *event)
 {
@@ -410,7 +417,12 @@ void ImageGlom::on_menupopup_activate_select_file()
     if(!uri.empty())
     {
       Dialog_Image_Progress* dialog;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED      
       Glib::RefPtr<Gtk::Builder> builder = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_image_progress");
+#else
+      std::auto_ptr<Glib::Error> error;      
+      Glib::RefPtr<Gtk::Builder> builder = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom.glade"), "dialog_image_progress", error);
+#endif
       builder->get_widget_derived("dialog_image_progress", dialog);
       if(dialog)
       {
