@@ -23,8 +23,8 @@
 
 #include <gtkmm.h>
 #include "layoutwidgetmenu.h"
-#include <glom/libglom/data_structure/layout/layoutitem_notebook.h>
-#include <libglademm.h>
+#include <libglom/data_structure/layout/layoutitem_notebook.h>
+#include <gtkmm/builder.h>
 
 namespace Glom
 {
@@ -36,7 +36,7 @@ class NotebookGlom
   public LayoutWidgetMenu
 {
 public:
-  explicit NotebookGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  explicit NotebookGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   explicit NotebookGlom();
   virtual ~NotebookGlom();
 
