@@ -19,11 +19,11 @@
  */
 
 #include "textviewglom.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 #include <gtkmm/messagedialog.h>
 #include "../dialog_invalid_data.h"
-#include <glom/libglom/data_structure/glomconversions.h>
-#include "../application.h"
+#include <libglom/data_structure/glomconversions.h>
+#include <glom/application.h>
 #include <glibmm/i18n.h>
 //#include <sstream> //For stringstream
 
@@ -31,7 +31,10 @@
 #include <ctime>     // for struct tm
 #include <iostream>   // for cout, endl
 
-TextViewGlom::TextViewGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& /* refGlade */)
+namespace Glom
+{
+
+TextViewGlom::TextViewGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::ScrolledWindow(cobject),
   m_glom_type(Field::TYPE_TEXT)
 {
@@ -46,7 +49,9 @@ TextViewGlom::TextViewGlom(Field::glom_field_type glom_type)
 
 void TextViewGlom::init()
 {
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   setup_menu();
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   set_shadow_type(Gtk::SHADOW_IN);
 
@@ -81,7 +86,7 @@ void TextViewGlom::check_for_change()
     bool success = false;
 
     sharedptr<const LayoutItem_Field>layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
-    Gnome::Gda::Value value = GlomConversions::parse_value(m_glom_type, new_text, layout_item->get_formatting_used().m_numeric_format, success);
+    Gnome::Gda::Value value = Conversions::parse_value(m_glom_type, new_text, layout_item->get_formatting_used().m_numeric_format, success);
 
     if(success)
     {
@@ -106,8 +111,15 @@ void TextViewGlom::check_for_change()
 
 bool TextViewGlom::on_textview_focus_out_event(GdkEventFocus* event)
 {
+  // TODO: Does the call below make sense even when compiled with
+  // default signal handlers? This function is a normal signal handler in
+  // any case.
+#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   //Call base class:
   bool result = Gtk::ScrolledWindow::on_focus_out_event(event);
+#else
+  bool result = false;
+#endif
 
   //The user has finished editing.
   check_for_change();
@@ -145,7 +157,7 @@ void TextViewGlom::set_value(const Gnome::Gda::Value& value)
 {
   sharedptr<const LayoutItem_Field>layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
   if(layout_item)
-    set_text(GlomConversions::get_text_for_gda_value(m_glom_type, value, layout_item->get_formatting_used().m_numeric_format));
+    set_text(Conversions::get_text_for_gda_value(m_glom_type, value, layout_item->get_formatting_used().m_numeric_format));
 }
 
 void TextViewGlom::set_text(const Glib::ustring& text)
@@ -163,9 +175,10 @@ Gnome::Gda::Value TextViewGlom::get_value() const
   sharedptr<const LayoutItem_Field>layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
 
   TextViewGlom* pNonConstThis = const_cast<TextViewGlom*>(this); //Gtk::TextBuffer::get_text() is non-const in gtkmm <=2.6.
-  return GlomConversions::parse_value(m_glom_type, pNonConstThis->m_TextView.get_buffer()->get_text(true), layout_item->get_formatting_used().m_numeric_format, success);
+  return Conversions::parse_value(m_glom_type, pNonConstThis->m_TextView.get_buffer()->get_text(true), layout_item->get_formatting_used().m_numeric_format, success);
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 bool TextViewGlom::on_button_press_event(GdkEventButton *event)
 {
   //Enable/Disable items.
@@ -198,6 +211,7 @@ bool TextViewGlom::on_button_press_event(GdkEventButton *event)
 
   return Gtk::ScrolledWindow::on_button_press_event(event);
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 App_Glom* TextViewGlom::get_application()
 {
@@ -206,3 +220,5 @@ App_Glom* TextViewGlom::get_application()
 
   return dynamic_cast<App_Glom*>(pWindow);
 }
+
+} //namespace Glom
